
Re-authentication
-------

**Description:**

Whenever an user is changing credentials such as his password, the user should always be 
challenged by the application to re-authenticate himself. This is in order to prevent an 
attacker to change credentials if ever an attacker could hijack another users session.


**Solution:**

User should always be challenged by the application to re-authenticate themselves  after 
changing their credentials, e-mail or doing other important data exchanges such as 
transferring money.

	